//
//  BMICalcViewController.m
//  BMICalc
//

#import "BMICalcViewController.h"

@implementation BMICalcViewController

@synthesize heightText;
@synthesize weightText;
@synthesize calcButton;
@synthesize resetButton;
@synthesize resultLabel;

- (void)viewDidLoad {
    [super viewDidLoad];    
    self.view.backgroundColor = [UIColor colorWithPatternImage:[UIImage imageNamed:@"bg-green.jpg"]];
}

- (void)viewDidUnload {
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
}

- (void)dealloc {
	[heightText release];
    [weightText release];
    [calcButton release];
    [resetButton release];
    [resultLabel release];
    [super dealloc];
}

// 身長・体重テキストのキーボードを隠す処理
- (void)textFieldResignFirstResponder {
    [heightText resignFirstResponder];
    [weightText resignFirstResponder];
}

// UITextFieldDelegateプロトコルで定義されているイベントメソッド
// キーボードのReturnキーが押された後に呼ばれる
- (BOOL)textFieldShouldReturn:(UITextField *)textField {
    [self textFieldResignFirstResponder];
    return YES;
}

// BMI計算実行処理
- (IBAction)executeCalc:(id) sender {
	
	// キーボードを隠す
    [self textFieldResignFirstResponder];
	
    // 身長テキストフィールドに入力された値（cm）をメートルに変換
    float height = [heightText.text floatValue]/100;
    
	// 体重テキストフィールドに入力された値を取得
    float weight = [weightText.text intValue];
    
    // BMI = 体重（kg）÷ (身長（m） × 身長（m）)
    float bmi = weight / (height * height);
    
    // BMI計算結果（少数点第1位まで）
    NSString *bmiStr = [ NSString stringWithFormat: @"%.1f", bmi];
    
    // 標準体重（kg） = 身長（m） × 身長（m） × BMI標準値（22）
    float stdWeight = (height * height) * 22;
    
    // 標準体重の計算結果（少数点第1位まで）
    NSString *stdWeightStr = [ NSString stringWithFormat: @"%.1f", stdWeight ];
    
    // 結果判定を行う
    NSString *result = @"";
	
	// BMIが18.51より小さければ「やせ気味」
    if (bmi < 18.5) {
        result = NSLocalizedString(@"wei_thin", @"Message for result thin.");		
    } 
	// BMIが18.5以上、25より小さければ「理想の体重」
	else if (bmi >= 18.5 && bmi < 25) {
        result = NSLocalizedString(@"wei_normal", @"Message for result normal.");		
    } 
	// それ以上の場合は「肥満」
	else {
        result = NSLocalizedString(@"wei_fat", @"Message for result fat.");
    }
    
    // 判定結果を結果ラベルに設定
    resultLabel.text = [NSString stringWithFormat:@"%@%@%@%@%@%@",
                        @"BMI\n", bmiStr, 
                        NSLocalizedString(@"stdWeight", @"Label for Standard weight."),
						stdWeightStr, @"kg\n\n",
                        result];
}

// リセット処理
- (IBAction)executeReset:(id) sender {
    
	// 各値をクリア
    heightText.text = @"";
    weightText.text = @"";
    resultLabel.text = @"";
}

@end